@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Config::Entities;
-$Config::Entities::VERSION = '1.04';
+$Config::Entities::VERSION = '1.05';
 # ABSTRACT: An multi-level overridable perl based configuration module
 # PODNAME: Config::Entities
 
@@ -19,6 +19,33 @@ sub new {
     return bless( {}, $class )->_init(@args);
 }
 
+sub as_hashref {
+    return _copy(@_);
+}
+
+sub _copy {
+    my ($value) = @_;
+
+    my $ref = ref($value);
+    if ($ref) {
+        if ( $ref eq 'ARRAY' ) {
+            return [ map { _copy($_) } @$value ];
+        }
+        elsif ( $ref eq 'HASH' || $value->isa('Config::Entities') ) {
+            return { map { $_ => _copy( $value->{$_} ) } keys(%$value) };
+        }
+        elsif ( $ref eq 'SCALAR' ) {
+            return $value;
+        }
+        else {
+            croak("unsupported type '$ref'");
+        }
+    }
+    else {
+        return $value;
+    }
+}
+
 sub _add_properties {
     my ( $self, $properties, $more_properties ) = @_;
 
@@ -196,7 +223,7 @@ Config::Entities - An multi-level overridable perl based configuration module
 
 =head1 VERSION
 
-version 1.04
+version 1.05
 
 =head1 SYNOPSIS
 
@@ -332,6 +359,11 @@ C<do FILE>
 
 =head1 METHODS
 
+=head2 as_hashref
+
+Will return a hashref representation of the current entities.  It will be a deep
+copy so changes to the hash will not affect the entities object.
+
 =head2 fill( $coordinate, $hashref, [%options] )
 
 Will iterate through the keys of C<$hashref> setting the associated value to the
